require 'fog/rackspace/auto_scale'
require 'fog/rackspace/block_storage'
require 'fog/rackspace/cdn'
require 'fog/rackspace/cdn_v2'
require 'fog/rackspace/compute'
require 'fog/rackspace/compute_v2'
require 'fog/rackspace/databases'
require 'fog/rackspace/dns'
require 'fog/rackspace/identity'
require 'fog/rackspace/load_balancers'
require 'fog/rackspace/monitoring'
require 'fog/rackspace/queues'
require 'fog/rackspace/storage'
require 'fog/rackspace/networking'
require 'fog/rackspace/orchestration'
require 'fog/rackspace/networking_v2'
