#
# AFAICT - This is basically undocumented - 6/18/2010 - freeformz
#

module Fog
  module Vcloud
    class Compute
      class Real
        basic_request :get_network_ips
      end
    end
  end
end
