#
# AFAICT this is basically undocumented ATM - 6/18/2010 - freeformz
#

module Fog
  module Vcloud
    class Compute
      class Real
        basic_request :get_network_ip
      end
    end
  end
end
