def storage_providers
  {
    :aws        => {
      :mocked => true
    },
    :hp         => {
      :mocked => true
    },
    :internetarchive => {
      :mocked => true
    },
    :local      => {
      :mocked => false
    },
    :ninefold   => {
      :mocked => false
    },
    :rackspace  => {
      :mocked => false
    }
  }
end
