class Bluebox
  module Compute
    module Formats
      PRODUCT = {
        'cost'        => String,
        'description' => String,
        'id'          => String
      },

      LOCATION = {
        'id'          => String,
        'description' => String
      }
    end
  end
end
