require 'fog/hp/block_storage'
require 'fog/hp/block_storage_v2'
require 'fog/hp/cdn'
require 'fog/hp/compute'
require 'fog/hp/compute_v2'
require 'fog/hp/dns'
require 'fog/hp/lb'
require 'fog/hp/network'
require 'fog/hp/storage'
