require 'fog/openstack/compute'
require 'fog/openstack/identity_v2'
require 'fog/openstack/identity_v3'
require 'fog/openstack/image'
require 'fog/openstack/metering'
require 'fog/openstack/network'
require 'fog/openstack/orchestration'
require 'fog/openstack/storage'
require 'fog/openstack/volume'
require 'fog/openstack/baremetal'
require 'fog/openstack/planning'
